#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb 13 10:20:19 2022

@author: richard
"""
from collections import namedtuple

ambiguous_dna_letters = "GATCRYWSMKHBVDN"
unambiguous_dna_letters = "GATC"
ambiguous_rna_letters = "GAUCRYWSMKHBVDN"
unambiguous_rna_letters = "GAUC"


protein_letters = "ACDEFGHIKLMNPQRSTVWY"

stop_codons = ["TAG", "TAA", "TGA"]

protein_names = {
    "SIDT1_HUMAN": "SID1 transmembrane family member 1",
    "MYO1E_HUMAN": "Unconventional myosin-Ie (Myosin-Ic) (Unconventional myosin 1E)",
    "PLPL4_HUMAN": "Patatin-like phospholipase domain-containing protein 4 (EC 3.1.1.3) (Protein GS2)",
    "CADM1_HUMAN": "Cell adhesion molecule 1 (Immunoglobulin superfamily member 4) (IgSF4) (Nectin-like protein 2) (NECL-2) (Spermatogenic immunoglobulin superfamily) (SgIgSF) (Synaptic cell adhesion molecule) (SynCAM) (Tumor suppressor in lung cancer 1) (TSLC-1)",
    "HYAL4_HUMAN": "Hyaluronidase-4 (Hyal-4) (EC 3.2.1.35) (Chondroitin sulfate endo-beta-N-acetylgalactosaminidase) (Chondroitin sulfate hydrolase) (CSHY) (Hyaluronoglucosaminidase-4)",
    "PRDX4_HUMAN": "Peroxiredoxin-4 (EC 1.11.1.24) (Antioxidant enzyme AOE372) (AOE37-2) (Peroxiredoxin IV) (Prx-IV) (Thioredoxin peroxidase AO372) (Thioredoxin-dependent peroxide reductase A0372) (Thioredoxin-dependent peroxiredoxin 4)",
    "CA054_HUMAN": "Uncharacterized protein C1orf54",
    "BMI1_HUMAN": "Polycomb complex protein BMI-1 (Polycomb group RING finger protein 4) (RING finger protein 51)",
    "SIRB2_HUMAN": "Signal-regulatory protein beta-2 (SIRP-beta-2) (Protein tyrosine phosphatase non-receptor type substrate 1-like 3) (Protein tyrosine phosphatase non-receptor type substrate protein)",
    "F149A_HUMAN": "Protein FAM149A",
    "MMP2_HUMAN": "72 kDa type IV collagenase (EC 3.4.24.24) (72 kDa gelatinase) (Gelatinase A) (Matrix metalloproteinase-2) (MMP-2) (TBE-1) [Cleaved into: PEX]",
    "TXND8_HUMAN": "Thioredoxin domain-containing protein 8 (Spermatid-specific thioredoxin-3) (Sptrx-3) (Thioredoxin-6)",
    "IF4E3_HUMAN": "Eukaryotic translation initiation factor 4E type 3 (eIF-4E type 3) (eIF-4E3) (eIF4E type 3) (eIF4E-3)",
    "AFG2H_HUMAN": "ATPase family protein 2 homolog (EC 3.6.4.10) (Spermatogenesis-associated factor protein) (Spermatogenesis-associated protein 5)",
    "THMS1_HUMAN": "Protein THEMIS (Thymocyte-expressed molecule involved in selection)",
    "ZNT3_HUMAN": "Zinc transporter 3 (ZnT-3) (Solute carrier family 30 member 3)",
    "SUV92_HUMAN": "Histone-lysine N-methyltransferase SUV39H2 (EC 2.1.1.355) (Histone H3-K9 methyltransferase 2) (H3-K9-HMTase 2) (Lysine N-methyltransferase 1B) (Suppressor of variegation 3-9 homolog 2) (Su(var)3-9 homolog 2)",
    "SYDE1_HUMAN": "Rho GTPase-activating protein SYDE1 (Synapse defective protein 1 homolog 1) (Protein syd-1 homolog 1)",
    "ANKR7_HUMAN": "Ankyrin repeat domain-containing protein 7 (Testis-specific protein TSA806)",
    "WDR27_HUMAN": "WD repeat-containing protein 27",
    "ARF3_HUMAN": "ADP-ribosylation factor 3",
    "HES4_HUMAN": "Transcription factor HES-4 (hHES4) (Class B basic helix-loop-helix protein 42) (bHLHb42) (Hairy and enhancer of split 4) (bHLH factor Hes4)",
    "ARPC3_HUMAN": "Actin-related protein 2/3 complex subunit 3 (Arp2/3 complex 21 kDa subunit) (p21-ARC)",
    "BOK_HUMAN": "Bcl-2-related ovarian killer protein (hBOK) (Bcl-2-like protein 9) (Bcl2-L-9)",
    "GAK8_HUMAN": "Endogenous retrovirus group K member 8 Gag polyprotein (HERV-K115 Gag protein) (HERV-K_8p23.1 provirus ancestral Gag polyprotein) (Gag polyprotein)",
    "OAZ1_HUMAN": "Ornithine decarboxylase antizyme 1 (AZ1) (ODC-Az)",
    "HDHD3_HUMAN": "Haloacid dehalogenase-like hydrolase domain-containing protein 3",
    "HNF4A_HUMAN": "Hepatocyte nuclear factor 4-alpha (HNF-4-alpha) (Nuclear receptor subfamily 2 group A member 1) (Transcription factor 14) (TCF-14) (Transcription factor HNF-4)",
    "CAPS1_HUMAN": "Calcium-dependent secretion activator 1 (Calcium-dependent activator protein for secretion 1) (CAPS-1)",
    "SSH1_HUMAN": "Protein phosphatase Slingshot homolog 1 (EC 3.1.3.16) (EC 3.1.3.48) (SSH-like protein 1) (SSH-1L) (hSSH-1L)",
    "MST1L_HUMAN": "Putative macrophage stimulating 1-like protein (Brain rescue factor 1) (BRF-1) (Hepatocyte growth factor-like protein homolog)",
    "PATE4_HUMAN": "Prostate and testis expressed protein 4 (PATE-like protein B) (PATE-B)",
    "DLDH_HUMAN": "Dihydrolipoyl dehydrogenase, mitochondrial (EC 1.8.1.4) (Dihydrolipoamide dehydrogenase) (Glycine cleavage system L protein)",
    "TMA16_HUMAN": "Translation machinery-associated protein 16",
    "TTC16_HUMAN": "Tetratricopeptide repeat protein 16 (TPR repeat protein 16)",
    "RL14_HUMAN": "60S ribosomal protein L14 (CAG-ISL 7) (Large ribosomal subunit protein eL14)",
    "PLCB3_HUMAN": "1-phosphatidylinositol 4,5-bisphosphate phosphodiesterase beta-3 (EC 3.1.4.11) (Phosphoinositide phospholipase C-beta-3) (Phospholipase C-beta-3) (PLC-beta-3)",
    "TRAP1_HUMAN": "Heat shock protein 75 kDa, mitochondrial (HSP 75) (TNFR-associated protein 1) (Tumor necrosis factor type 1 receptor-associated protein) (TRAP-1)",
    "MAEA_HUMAN": "E3 ubiquitin-protein transferase MAEA (EC 2.3.2.27) (Cell proliferation-inducing gene 5 protein) (Erythroblast macrophage protein) (Human lung cancer oncogene 10 protein) (HLC-10) (Macrophage erythroblast attacher) (P44EMLP)",
    "C2D1B_HUMAN": "Coiled-coil and C2 domain-containing protein 1B (Five prime repressor element under dual repression-binding protein 2) (FRE under dual repression-binding protein 2) (Freud-2)",
    "TLCD1_HUMAN": "TLC domain-containing protein 1 (Calfacilitin)",
    "RHG31_HUMAN": "Rho GTPase-activating protein 31 (Cdc42 GTPase-activating protein)",
    "NKX61_HUMAN": "Homeobox protein Nkx-6.1 (Homeobox protein NK-6 homolog A)",
    "UCHL3_HUMAN": "Ubiquitin carboxyl-terminal hydrolase isozyme L3 (UCH-L3) (EC 3.4.19.12) (Ubiquitin thioesterase L3)",
    "PROZ_HUMAN": "Vitamin K-dependent protein Z",
    "NOX1_HUMAN": "NADPH oxidase 1 (NOX-1) (EC 1.-.-.-) (Mitogenic oxidase 1) (MOX-1) (NADH/NADPH mitogenic oxidase subunit P65-MOX) (NOH-1)",
    "F1892_HUMAN": "Protein FAM189A2 (Protein X123)",
    "SUMO3_HUMAN": "Small ubiquitin-related modifier 3 (SUMO-3) (SMT3 homolog 1) (SUMO-2) (Ubiquitin-like protein SMT3A) (Smt3A)",
    "IKZF5_HUMAN": "Zinc finger protein Pegasus (Ikaros family zinc finger protein 5)",
    "IF4A2_HUMAN": "Eukaryotic initiation factor 4A-II (eIF-4A-II) (eIF4A-II) (EC 3.6.4.13) (ATP-dependent RNA helicase eIF4A-2)",
    "CJ126_HUMAN": "Putative uncharacterized protein C10orf126",
    "GDF2_HUMAN": "Growth/differentiation factor 2 (GDF-2) (Bone morphogenetic protein 9) (BMP-9)",
    "GASP1_HUMAN": "G-protein coupled receptor-associated sorting protein 1 (GASP-1)",
    "RPB2_HUMAN": "DNA-directed RNA polymerase II subunit RPB2 (EC 2.7.7.6) (DNA-directed RNA polymerase II 140 kDa polypeptide) (DNA-directed RNA polymerase II subunit B) (RNA polymerase II subunit 2) (RNA polymerase II subunit B2)",
    "SDE2_HUMAN": "Replication stress response regulator SDE2",
    "OR4A8_HUMAN": "Olfactory receptor 4A8 (Olfactory receptor OR11-110)",
    "BRI3B_HUMAN": "BRI3-binding protein (I3-binding protein) (Cervical cancer 1 proto-oncogene-binding protein KG19) (HCCRBP-1)",
    "KTU_HUMAN": "Protein kintoun (Dynein assembly factor 2, axonemal)",
    "MOES_HUMAN": "Moesin (Membrane-organizing extension spike protein)",
    "KBP_HUMAN": "KIF-binding protein (KIF1-binding protein) (Kinesin family binding protein)",
    "HPT_HUMAN": "Haptoglobin (Zonulin) [Cleaved into: Haptoglobin alpha chain; Haptoglobin beta chain]",
    "HAVR2_HUMAN": "Hepatitis A virus cellular receptor 2 (HAVcr-2) (T-cell immunoglobulin and mucin domain-containing protein 3) (TIMD-3) (T-cell immunoglobulin mucin receptor 3) (TIM-3) (T-cell membrane protein 3) (CD antigen CD366)",
    "SEM6B_HUMAN": "Semaphorin-6B (Semaphorin-Z) (Sema Z)",
    "MED12_HUMAN": "Mediator of RNA polymerase II transcription subunit 12 (Activator-recruited cofactor 240 kDa component) (ARC240) (CAG repeat protein 45) (Mediator complex subunit 12) (OPA-containing protein) (Thyroid hormone receptor-associated protein complex 230 kDa component) (Trap230) (Trinucleotide repeat-containing gene 11 protein)",
    "TIGD3_HUMAN": "Tigger transposable element-derived protein 3",
    "ZN200_HUMAN": "Zinc finger protein 200",
    "KCC4_HUMAN": "Calcium/calmodulin-dependent protein kinase type IV (CaMK IV) (EC 2.7.11.17) (CaM kinase-GR)",
    "AGM1_HUMAN": "Phosphoacetylglucosamine mutase (PAGM) (EC 5.4.2.3) (Acetylglucosamine phosphomutase) (N-acetylglucosamine-phosphate mutase) (Phosphoglucomutase-3) (PGM 3)",
    "TNNT1_HUMAN": "Troponin T, slow skeletal muscle (TnTs) (Slow skeletal muscle troponin T) (sTnT)",
    "CP7A1_HUMAN": "Cytochrome P450 7A1 (24-hydroxycholesterol 7-alpha-hydroxylase) (EC 1.14.14.26) (CYPVII) (Cholesterol 7-alpha-hydroxylase) (Cholesterol 7-alpha-monooxygenase) (EC 1.14.14.23)",
    "CNIH4_HUMAN": "Protein cornichon homolog 4 (CNIH-4) (Cornichon family AMPA receptor auxiliary protein 4)",
    "CTGEF_HUMAN": "cTAGE family member 15 (Protein cTAGE-15)",
    "HXA2_HUMAN": "Homeobox protein Hox-A2 (Homeobox protein Hox-1K)",
    "FBLN2_HUMAN": "Fibulin-2 (FIBL-2)",
    "ADH6_HUMAN": "Alcohol dehydrogenase 6 (EC 1.1.1.1)",
    "TGFR1_HUMAN": "TGF-beta receptor type-1 (TGFR-1) (EC 2.7.11.30) (Activin A receptor type II-like protein kinase of 53kD) (Activin receptor-like kinase 5) (ALK-5) (ALK5) (Serine/threonine-protein kinase receptor R4) (SKR4) (TGF-beta type I receptor) (Transforming growth factor-beta receptor type I) (TGF-beta receptor type I) (TbetaR-I)",
    "TGDS_HUMAN": "dTDP-D-glucose 4,6-dehydratase (EC 4.2.1.46)",
    "ADPRM_HUMAN": "Manganese-dependent ADP-ribose/CDP-alcohol diphosphatase (EC 3.6.1.13) (EC 3.6.1.16) (EC 3.6.1.53) (ADPRibase-Mn) (CDP-choline phosphohydrolase)",
    "EXC6B_HUMAN": "Exocyst complex component 6B (Exocyst complex component Sec15B) (SEC15-like protein 2)",
    "IN35_HUMAN": "Interferon-induced 35 kDa protein (IFP 35) (Ifi-35)",
    "ZN461_HUMAN": "Zinc finger protein 461 (Gonadotropin-inducible ovary transcription repressor 1) (GIOT-1)",
    "CDK17_HUMAN": "Cyclin-dependent kinase 17 (EC 2.7.11.22) (Cell division protein kinase 17) (PCTAIRE-motif protein kinase 2) (Serine/threonine-protein kinase PCTAIRE-2)",
    "PRR5_HUMAN": "Proline-rich protein 5 (Protein observed with Rictor-1) (Protor-1)",
    "AXIN1_HUMAN": "Axin-1 (Axis inhibition protein 1) (hAxin)",
    "CCD57_HUMAN": "Coiled-coil domain-containing protein 57",
    "SMAP2_HUMAN": "Stromal membrane-associated protein 2 (Stromal membrane-associated protein 1-like)",
    "TLK1_HUMAN": "Serine/threonine-protein kinase tousled-like 1 (EC 2.7.11.1) (PKU-beta) (Tousled-like kinase 1)",
    "SORC3_HUMAN": "VPS10 domain-containing receptor SorCS3",
    "TNR27_HUMAN": "Tumor necrosis factor receptor superfamily member 27 (X-linked ectodysplasin-A2 receptor) (EDA-A2 receptor)",
    "FHL17_HUMAN": "Ferritin heavy polypeptide-like 17 (Cancer/testis antigen 38) (CT38)",
    "KVD26_HUMAN": "Immunoglobulin kappa variable 2D-26",
    "FHL3_HUMAN": "Four and a half LIM domains protein 3 (FHL-3) (Skeletal muscle LIM-protein 2) (SLIM-2)",
    "QOR_HUMAN": "Quinone oxidoreductase (EC 1.6.5.5) (NADPH:quinone reductase) (Zeta-crystallin)",
    "MOT4_HUMAN": "Monocarboxylate transporter 4 (MCT 4) (Solute carrier family 16 member 3)",
    "CH014_HUMAN": "Putative uncharacterized protein encoded by LINC00208",
    "TM182_HUMAN": "Transmembrane protein 182",
    "ESYT1_HUMAN": "Extended synaptotagmin-1 (E-Syt1) (Membrane-bound C2 domain-containing protein)",
    "DAB2P_HUMAN": "Disabled homolog 2-interacting protein (DAB2 interaction protein) (DAB2-interacting protein) (ASK-interacting protein 1) (AIP-1) (DOC-2/DAB-2 interactive protein)",
    "ECE1_HUMAN": "Endothelin-converting enzyme 1 (ECE-1) (EC 3.4.24.71)",
    "CIPC_HUMAN": "CLOCK-interacting pacemaker (CLOCK-interacting circadian protein)",
    "GBB2_HUMAN": "Guanine nucleotide-binding protein G(I)/G(S)/G(T) subunit beta-2 (G protein subunit beta-2) (Transducin beta chain 2)",
    "RIOK2_HUMAN": "Serine/threonine-protein kinase RIO2 (EC 2.7.11.1) (RIO kinase 2)",
    "S2536_HUMAN": "Solute carrier family 25 member 36",
    "EPHB2_HUMAN": "Ephrin type-B receptor 2 (EC 2.7.10.1) (Developmentally-regulated Eph-related tyrosine kinase) (ELK-related tyrosine kinase) (EPH tyrosine kinase 3) (EPH-like kinase 5) (EK5) (hEK5) (Renal carcinoma antigen NY-REN-47) (Tyrosine-protein kinase TYRO5) (Tyrosine-protein kinase receptor EPH-3) [Cleaved into: EphB2/CTF1; EphB2/CTF2]",
    "CRFM7_HUMAN": "CHRNA7-FAM7A fusion protein (CHRNA7-DR1) (D-10)",
    "NR6A1_HUMAN": "Nuclear receptor subfamily 6 group A member 1 (Germ cell nuclear factor) (GCNF) (hGCNF) (Retinoid receptor-related testis-specific receptor) (RTR) (hRTR)",
    "MSS51_HUMAN": "Putative protein MSS51 homolog, mitochondrial (Zinc finger MYND domain-containing protein 17)",
    "EMAL1_HUMAN": "Echinoderm microtubule-associated protein-like 1 (EMAP-1) (HuEMAP-1)",
    "TM171_HUMAN": "Transmembrane protein 171",
    "U2AFL_HUMAN": "Putative U2 small nuclear ribonucleoprotein auxiliary factor 35 kDa subunit-related protein 1 (CCCH type zinc finger, RNA-binding motif and serine/arginine rich protein 1) (U2(RNU2) small nuclear RNA auxiliary factor 1-like 1)",
    "DYH11_HUMAN": "Dynein heavy chain 11, axonemal (Axonemal beta dynein heavy chain 11) (Ciliary dynein heavy chain 11)",
    "PLPR1_HUMAN": "Phospholipid phosphatase-related protein type 1 (Lipid phosphate phosphatase-related protein type 1) (Plasticity-related gene 3 protein) (PRG-3)",
    "OR2W5_HUMAN": "Putative olfactory receptor 2W5",
    "F209A_HUMAN": "Protein FAM209A",
    "LIPP_HUMAN": "Pancreatic triacylglycerol lipase (PL) (PTL) (Pancreatic lipase) (EC 3.1.1.3)",
    "MANEL_HUMAN": "Glycoprotein endo-alpha-1,2-mannosidase-like protein (EC 3.2.1.-)",
    "OPN5_HUMAN": "Opsin-5 (G-protein coupled receptor 136) (G-protein coupled receptor PGR12) (Neuropsin) (Transmembrane protein 13)",
    "ZFAN5_HUMAN": "AN1-type zinc finger protein 5 (Zinc finger A20 domain-containing protein 2) (Zinc finger protein 216)",
    "KAT2B_HUMAN": "Histone acetyltransferase KAT2B (EC 2.3.1.48) (Histone acetyltransferase PCAF) (Histone acetylase PCAF) (Lysine acetyltransferase 2B) (P300/CBP-associated factor) (P/CAF) (Spermidine acetyltransferase KAT2B) (EC 2.3.1.57)",
    "PCY1A_HUMAN": "Choline-phosphate cytidylyltransferase A (EC 2.7.7.15) (CCT-alpha) (CTP:phosphocholine cytidylyltransferase A) (CCT A) (CT A) (Phosphorylcholine transferase A)",
    "ATP8_HUMAN": "ATP synthase protein 8 (A6L) (F-ATPase subunit 8)",
    "SG11B_HUMAN": "Sperm-associated antigen 11B (Human epididymis-specific protein 2) (He2) (Protein EP2) (Sperm antigen HE2)",
    "O51M1_HUMAN": "Olfactory receptor 51M1 (Odorant receptor HOR5'beta7) (Olfactory receptor OR11-40)",
    "MUC1_HUMAN": "Mucin-1 (MUC-1) (Breast carcinoma-associated antigen DF3) (Cancer antigen 15-3) (CA 15-3) (Carcinoma-associated mucin) (Episialin) (H23AG) (Krebs von den Lungen-6) (KL-6) (PEMT) (Peanut-reactive urinary mucin) (PUM) (Polymorphic epithelial mucin) (PEM) (Tumor-associated epithelial membrane antigen) (EMA) (Tumor-associated mucin) (CD antigen CD227) [Cleaved into: Mucin-1 subunit alpha (MUC1-NT) (MUC1-alpha); Mucin-1 subunit beta (MUC1-beta) (MUC1-CT)]",
    "ZN808_HUMAN": "Zinc finger protein 808",
    "CR012_HUMAN": "Uncharacterized protein C18orf12 (Protein HEIL1)",
    "SO5A1_HUMAN": "Solute carrier organic anion transporter family member 5A1 (Organic anion transporter polypeptide-related protein 4) (OATP-RP4) (OATPRP4) (Solute carrier family 21 member 15)",
    "MTAP_HUMAN": "S-methyl-5'-thioadenosine phosphorylase (EC 2.4.2.28) (5'-methylthioadenosine phosphorylase) (MTA phosphorylase) (MTAP) (MTAPase)",
    "ALX1_HUMAN": "ALX homeobox protein 1 (Cartilage homeoprotein 1) (CART-1)",
    "NAT8L_HUMAN": "N-acetylaspartate synthetase (NAA synthetase) (EC 2.3.1.17) (Camello-like protein 3) (N-acetyltransferase 8-like protein)",
    "PPIL2_HUMAN": "RING-type E3 ubiquitin-protein ligase PPIL2 (EC 2.3.2.27) (CYC4) (Cyclophilin-60) (Cyclophilin-like protein Cyp-60) (Cyp60) (hCyP-60) (Probable inactive peptidyl-prolyl cis-trans isomerase-like 2) (PPIase) (Rotamase PPIL2)",
    "RREB1_HUMAN": "Ras-responsive element-binding protein 1 (RREB-1) (Finger protein in nuclear bodies) (Raf-responsive zinc finger protein LZ321) (Zinc finger motif enhancer-binding protein 1) (Zep-1)",
    "CP1B1_HUMAN": "Cytochrome P450 1B1 (EC 1.14.14.1) (CYPIB1) (Hydroperoxy icosatetraenoate dehydratase) (EC 4.2.1.152)",
    "SYCP2_HUMAN": "Synaptonemal complex protein 2 (SCP-2) (Synaptonemal complex lateral element protein) (hsSCP2)",
    "ACRC_HUMAN": "Acidic repeat-containing protein (Germ cell nuclear antigen)",
    "EDF1_HUMAN": "Endothelial differentiation-related factor 1 (EDF-1) (Multiprotein-bridging factor 1) (MBF1)",
    "O14A2_HUMAN": "Olfactory receptor 14A2 (Olfactory receptor 5AX1) (Olfactory receptor OR1-31)",
    "S2533_HUMAN": "Solute carrier family 25 member 33 (Bone marrow stromal cell mitochondrial carrier protein) (BMSC-MCP) (HuBMSC-MCP) (Protein PNC1)",
    "CAC1S_HUMAN": "Voltage-dependent L-type calcium channel subunit alpha-1S (Calcium channel, L type, alpha-1 polypeptide, isoform 3, skeletal muscle) (Voltage-gated calcium channel subunit alpha Cav1.1)",
    "ACTHR_HUMAN": "Adrenocorticotropic hormone receptor (ACTH receptor) (ACTH-R) (Adrenocorticotropin receptor) (Melanocortin receptor 2) (MC2-R)",
    "F183A_HUMAN": "Protein FAM183A",
    "ARSK_HUMAN": "Arylsulfatase K (ASK) (EC 3.1.6.-) (Telethon sulfatase)",
    "LMF2_HUMAN": "Lipase maturation factor 2 (Transmembrane protein 112B) (Transmembrane protein 153)",
    "SPIN3_HUMAN": "Spindlin-3 (Spindlin-like protein 3) (SPIN-3)",
    "BAG5_HUMAN": "BAG family molecular chaperone regulator 5 (BAG-5) (Bcl-2-associated athanogene 5)",
    "GBRB1_HUMAN": "Gamma-aminobutyric acid receptor subunit beta-1 (GABA(A) receptor subunit beta-1)",
    "BNIP2_HUMAN": "BCL2/adenovirus E1B 19 kDa protein-interacting protein 2",
    "ROS1_HUMAN": "Proto-oncogene tyrosine-protein kinase ROS (EC 2.7.10.1) (Proto-oncogene c-Ros) (Proto-oncogene c-Ros-1) (Receptor tyrosine kinase c-ros oncogene 1) (c-Ros receptor tyrosine kinase)",
    "NANOG_HUMAN": "Homeobox protein NANOG (Homeobox transcription factor Nanog) (hNanog)",
    "TIG1_HUMAN": "Retinoic acid receptor responder protein 1 (Phorbol ester-induced gene 1 protein) (PERG-1) (RAR-responsive protein TIG1) (Tazarotene-induced gene 1 protein)",
    "T53I1_HUMAN": "Tumor protein p53-inducible nuclear protein 1 (Stress-induced protein) (p53-dependent damage-inducible nuclear protein 1) (p53DINP1)",
    "SCN7A_HUMAN": "Sodium channel protein type 7 subunit alpha (Putative voltage-gated sodium channel subunit alpha Nax) (Sodium channel protein cardiac and skeletal muscle subunit alpha) (Sodium channel protein type VII subunit alpha)",
    "TLR7_HUMAN": "Toll-like receptor 7",
    "PLXA3_HUMAN": "Plexin-A3 (Plexin-4) (Semaphorin receptor SEX)",
    "EFS_HUMAN": "Embryonal Fyn-associated substrate (hEFS) (Cas scaffolding protein family member 3)",
    "SSX7_HUMAN": "Protein SSX7",
    "FLRT3_HUMAN": "Leucine-rich repeat transmembrane protein FLRT3 (Fibronectin-like domain-containing leucine-rich transmembrane protein 3)",
    "CC138_HUMAN": "Coiled-coil domain-containing protein 138",
    "SRTM2_HUMAN": "Serine-rich and transmembrane domain-containing 2",
    "NDUB3_HUMAN": "NADH dehydrogenase [ubiquinone] 1 beta subcomplex subunit 3 (Complex I-B12) (CI-B12) (NADH-ubiquinone oxidoreductase B12 subunit)",
    "AP1M2_HUMAN": "AP-1 complex subunit mu-2 (AP-mu chain family member mu1B) (Adaptor protein complex AP-1 subunit mu-2) (Adaptor-related protein complex 1 subunit mu-2) (Clathrin assembly protein complex 1 mu-2 medium chain 2) (Golgi adaptor HA1/AP1 adaptin mu-2 subunit) (Mu-adaptin 2) (Mu1B-adaptin)",
    "O4C45_HUMAN": "Olfactory receptor 4C45",
    "ZAR1_HUMAN": "Zygote arrest protein 1 (Oocyte-specific maternal effect factor)",
    "MTMRC_HUMAN": "Myotubularin-related protein 12 (Inactive phosphatidylinositol 3-phosphatase 12) (Phosphatidylinositol 3 phosphate 3-phosphatase adapter subunit) (3-PAP) (3-phosphatase adapter protein)",
    "MXRA5_HUMAN": "Matrix-remodeling-associated protein 5 (Adhesion protein with leucine-rich repeats and immunoglobulin domains related to perlecan) (Adlican)",
    "CIDEC_HUMAN": "Cell death activator CIDE-3 (Cell death-inducing DFFA-like effector protein C) (Fat-specific protein FSP27 homolog)",
    "S2534_HUMAN": "Solute carrier family 25 member 34",
    "HOT_HUMAN": "Hydroxyacid-oxoacid transhydrogenase, mitochondrial (HOT) (EC 1.1.99.24) (Alcohol dehydrogenase iron-containing protein 1) (ADHFe1) (Fe-containing alcohol dehydrogenase)",
    "MEIS3_HUMAN": "Homeobox protein Meis3 (Meis1-related protein 2)",
    "ITB7_HUMAN": "Integrin beta-7 (Gut homing receptor beta subunit)",
    "CY1_HUMAN": "Cytochrome c1, heme protein, mitochondrial (EC 7.1.1.8) (Complex III subunit 4) (Complex III subunit IV) (Cytochrome b-c1 complex subunit 4) (Ubiquinol-cytochrome-c reductase complex cytochrome c1 subunit) (Cytochrome c-1)",
    "PAL4F_HUMAN": "Peptidyl-prolyl cis-trans isomerase A-like 4F (PPIase A-like 4F) (EC 5.2.1.8)",
    "HV781_HUMAN": "Probable non-functional immunoglobulin heavy variable 7-81",
    "NU107_HUMAN": "Nuclear pore complex protein Nup107 (107 kDa nucleoporin) (Nucleoporin Nup107)",
    "DKC1_HUMAN": "H/ACA ribonucleoprotein complex subunit DKC1 (EC 5.4.99.-) (CBF5 homolog) (Dyskerin) (Nopp140-associated protein of 57 kDa) (Nucleolar protein NAP57) (Nucleolar protein family A member 4) (snoRNP protein DKC1)",
    "PSD3_HUMAN": "PH and SEC7 domain-containing protein 3 (Epididymis tissue protein Li 20mP) (Exchange factor for ADP-ribosylation factor guanine nucleotide factor 6 D) (Exchange factor for ARF6 D) (Hepatocellular carcinoma-associated antigen 67) (Pleckstrin homology and SEC7 domain-containing protein 3)",
    "CFA44_HUMAN": "Cilia- and flagella-associated protein 44 (WD repeat-containing protein 52)",
    "CEP72_HUMAN": "Centrosomal protein of 72 kDa (Cep72)",
    "CABP2_HUMAN": "Calcium-binding protein 2 (CaBP2)",
    "SP7_HUMAN": "Transcription factor Sp7 (Zinc finger protein osterix)",
    "CP4AB_HUMAN": "Cytochrome P450 4A11 (EC 1.14.14.1) (20-hydroxyeicosatetraenoic acid synthase) (20-HETE synthase) (CYP4AII) (CYPIVA11) (Cytochrome P-450HK-omega) (Cytochrome P450HL-omega) (Fatty acid omega-hydroxylase) (Lauric acid omega-hydroxylase) (Long-chain fatty acid omega-monooxygenase) (EC 1.14.14.80)",
    "TTBK1_HUMAN": "Tau-tubulin kinase 1 (EC 2.7.11.1) (Brain-derived tau kinase)",
    "GATA_HUMAN": "Glutamyl-tRNA(Gln) amidotransferase subunit A, mitochondrial (Glu-AdT subunit A) (EC 6.3.5.7) (Glutaminyl-tRNA synthase-like protein 1)",
    "A16A1_HUMAN": "Aldehyde dehydrogenase family 16 member A1",
    "SHSA4_HUMAN": "Protein shisa-4 (Transmembrane protein 58)",
    "FGF20_HUMAN": "Fibroblast growth factor 20 (FGF-20)",
    "CBLL2_HUMAN": "E3 ubiquitin-protein ligase CBLL2 (EC 2.3.2.27) (Cbl proto-oncogene-like protein 2) (RING-type E3 ubiquitin transferase ZNF645) (Zinc finger protein 645) (c-Cbl-like protein 2)",
    "SMOC1_HUMAN": "SPARC-related modular calcium-binding protein 1 (Secreted modular calcium-binding protein 1) (SMOC-1)",
    "MUC21_HUMAN": "Mucin-21 (MUC-21) (Epiglycanin)",
    "CI116_HUMAN": "UPF0691 protein C9orf116 (p53-induced expression in RB-null cells protein 1) (Pierce1)",
    "KSYK_HUMAN": "Tyrosine-protein kinase SYK (EC 2.7.10.2) (Spleen tyrosine kinase) (p72-Syk)",
    "SUMO5_HUMAN": "Small ubiquitin-related modifier 5 (SUMO-5) (SUMO1 pseudogene 1) (Ubiquitin-like 2) (Ubiquitin-like 6)",
    "C1GLC_HUMAN": "C1GALT1-specific chaperone 1 (C38H2-like protein 1) (C38H2-L1) (Core 1 beta1,3-galactosyltransferase 2) (C1Gal-T2) (C1GalT2) (Core 1 beta3-Gal-T2) (Core 1 beta3-galactosyltransferase-specific molecular chaperone)",
    "GTSC1_HUMAN": "Gilles de la Tourette syndrome chromosomal region candidate gene 1 protein",
    "STML1_HUMAN": "Stomatin-like protein 1 (SLP-1) (EPB72-like protein 1) (Protein unc-24 homolog) (Stomatin-related protein) (STORP)",
    "C163A_HUMAN": "Scavenger receptor cysteine-rich type 1 protein M130 (Hemoglobin scavenger receptor) (CD antigen CD163) [Cleaved into: Soluble CD163 (sCD163)]",
    "T4S1_HUMAN": "Transmembrane 4 L6 family member 1 (Membrane component chromosome 3 surface marker 1) (Tumor-associated antigen L6)",
    "CTXN3_HUMAN": "Cortexin-3 (Kidney and brain-expressed protein)",
    "NEDD4_HUMAN": "E3 ubiquitin-protein ligase NEDD4 (EC 2.3.2.26) (Cell proliferation-inducing gene 53 protein) (HECT-type E3 ubiquitin transferase NEDD4) (Neural precursor cell expressed developmentally down-regulated protein 4) (NEDD-4)",
    "EMC10_HUMAN": "ER membrane protein complex subunit 10 (Hematopoietic signal peptide-containing membrane domain-containing protein 1)",
    "PASK_HUMAN": "PAS domain-containing serine/threonine-protein kinase (PAS-kinase) (PASKIN) (hPASK) (EC 2.7.11.1)",
    "KRA61_HUMAN": "Keratin-associated protein 6-1",
    "TMPS9_HUMAN": "Transmembrane protease serine 9 (EC 3.4.21.-) (Polyserase-I) (Polyserine protease 1) (Polyserase-1) [Cleaved into: Serase-1; Serase-2; Serase-3]",
    "MRC1_HUMAN": "Macrophage mannose receptor 1 (MMR) (C-type lectin domain family 13 member D) (C-type lectin domain family 13 member D-like) (Human mannose receptor) (hMR) (Macrophage mannose receptor 1-like protein 1) (CD antigen CD206)",
    "ABTB2_HUMAN": "Ankyrin repeat and BTB/POZ domain-containing protein 2",
    "TR10A_HUMAN": "Tumor necrosis factor receptor superfamily member 10A (Death receptor 4) (TNF-related apoptosis-inducing ligand receptor 1) (TRAIL receptor 1) (TRAIL-R1) (CD antigen CD261)",
    "RUSD1_HUMAN": "RNA pseudouridylate synthase domain-containing protein 1 (Ribosomal large subunit pseudouridine synthase C-like protein)",
    "PTCD1_HUMAN": "Pentatricopeptide repeat-containing protein 1, mitochondrial",
    "TVBJ1_HUMAN": "T cell receptor beta variable 10-1",
    "GLPA_HUMAN": "Glycophorin-A (MN sialoglycoprotein) (PAS-2) (Sialoglycoprotein alpha) (CD antigen CD235a)",
    "HV511_HUMAN": "Probable non-functional immunoglobulin heavy variable 8-51-1",
    "L37A3_HUMAN": "Leucine-rich repeat-containing protein 37A3",
    "S29P2_HUMAN": "Putative protein SNX29P2 (RUN domain-containing protein 2C) (Sorting nexin 29 protein pseudogene 2)",
    "AL1A2_HUMAN": "Retinal dehydrogenase 2 (RALDH 2) (RalDH2) (EC 1.2.1.36) (Aldehyde dehydrogenase family 1 member A2) (Retinaldehyde-specific dehydrogenase type 2) (RALDH(II))",
    "PERL_HUMAN": "Lactoperoxidase (LPO) (EC 1.11.1.7) (Salivary peroxidase) (SPO)",
    "CCNH_HUMAN": "Cyclin-H (MO15-associated protein) (p34) (p37)",
    "WASH2_HUMAN": "WAS protein family homolog 2 (CXYorf1-like protein on chromosome 2) (Protein FAM39B)",
    "O4A15_HUMAN": "Olfactory receptor 4A15 (Olfactory receptor OR11-118)",
    "CT459_HUMAN": "Cancer/testis antigen family 45 member A9 (Cancer/testis antigen 45A9)",
    "TLDC2_HUMAN": "TLD domain-containing protein 2 (TBC/LysM-associated domain-containing protein 2)",
    "GATC_HUMAN": "Glutamyl-tRNA(Gln) amidotransferase subunit C, mitochondrial (Glu-AdT subunit C) (EC 6.3.5.-) (Protein 15E1.2)",
    "MSH5_HUMAN": "MutS protein homolog 5 (hMSH5)",
    "CNTN1_HUMAN": "Contactin-1 (Glycoprotein gp135) (Neural cell surface protein F3)",
    "ELOV5_HUMAN": "Elongation of very long chain fatty acids protein 5 (EC 2.3.1.199) (3-keto acyl-CoA synthase ELOVL5) (ELOVL fatty acid elongase 5) (ELOVL FA elongase 5) (Fatty acid elongase 1) (hELO1) (Very long chain 3-ketoacyl-CoA synthase 5) (Very long chain 3-oxoacyl-CoA synthase 5)",
    "GRM1_HUMAN": "Metabotropic glutamate receptor 1 (mGluR1)",
    "ORC6_HUMAN": "Origin recognition complex subunit 6",
    "TWST2_HUMAN": "Twist-related protein 2 (Class A basic helix-loop-helix protein 39) (bHLHa39) (Dermis-expressed protein 1) (Dermo-1)",
    "LV150_HUMAN": "Probable non-functional immunoglobulin lambda variable 1-50",
    "GRN_HUMAN": "Progranulin (PGRN) (Acrogranin) (Epithelin precursor) (Glycoprotein of 88 Kda) (GP88) (Glycoprotein 88) (Granulin precursor) (PC cell-derived growth factor) (PCDGF) (Proepithelin) (PEPI) [Cleaved into: Paragranulin; Granulin-1 (Granulin G); Granulin-2 (Granulin F); Granulin-3 (Epithelin-2) (Granulin B); Granulin-4 (Epithelin-1) (Granulin A); Granulin-5 (Granulin C); Granulin-6 (Granulin D); Granulin-7 (Granulin E)]",
    "PEX12_HUMAN": "Peroxisome assembly protein 12 (Peroxin-12) (Peroxisome assembly factor 3) (PAF-3)",
    "PCP2_HUMAN": "Purkinje cell protein 2 homolog",
    "GON1_HUMAN": "Progonadoliberin-1 (Progonadoliberin I) [Cleaved into: Gonadoliberin-1 (Gonadoliberin I) (Gonadorelin) (Gonadotropin-releasing hormone I) (GnRH-I) (Luliberin I) (Luteinizing hormone-releasing hormone I) (LH-RH I); GnRH-associated peptide 1 (GnRH-associated peptide I)]",
    "OMA1_HUMAN": "Metalloendopeptidase OMA1, mitochondrial (EC 3.4.24.-) (Metalloprotease-related protein 1) (MPRP-1) (Overlapping with the m-AAA protease 1 homolog)",
    "ADRB2_HUMAN": "Beta-2 adrenergic receptor (Beta-2 adrenoreceptor) (Beta-2 adrenoceptor)",
    "MFNG_HUMAN": "Beta-1,3-N-acetylglucosaminyltransferase manic fringe (EC 2.4.1.222) (O-fucosylpeptide 3-beta-N-acetylglucosaminyltransferase)",
    "CL042_HUMAN": "Uncharacterized protein C12orf42",
    "CU062_HUMAN": "Uncharacterized protein C21orf62 (B37)",
    "SCNBA_HUMAN": "Sodium channel protein type 11 subunit alpha (Peripheral nerve sodium channel 5) (PN5) (Sensory neuron sodium channel 2) (Sodium channel protein type XI subunit alpha) (Voltage-gated sodium channel subunit alpha Nav1.9) (hNaN)",
    "SGTA_HUMAN": "Small glutamine-rich tetratricopeptide repeat-containing protein alpha (Alpha-SGT) (Vpu-binding protein) (UBP)",
    "PLAC1_HUMAN": "Placenta-specific protein 1",
    "NPIA5_HUMAN": "Nuclear pore complex-interacting protein family member A5",
    "APC4_HUMAN": "Anaphase-promoting complex subunit 4 (APC4) (Cyclosome subunit 4)",
    "SF3B5_HUMAN": "Splicing factor 3B subunit 5 (SF3b5) (Pre-mRNA-splicing factor SF3b 10 kDa subunit)",
    "OR4F5_HUMAN": "Olfactory receptor 4F5",
    "IFN17_HUMAN": "Interferon alpha-17 (IFN-alpha-17) (Interferon alpha-88) (Interferon alpha-I') (LeIF I) (Interferon alpha-T)",
    "PRSR2_HUMAN": "Proline and serine-rich protein 2",
    "CO3_HUMAN": "Complement C3 (C3 and PZP-like alpha-2-macroglobulin domain-containing protein 1) [Cleaved into: Complement C3 beta chain; C3-beta-c (C3bc); Complement C3 alpha chain; C3a anaphylatoxin; Acylation stimulating protein (ASP) (C3adesArg); Complement C3b alpha' chain; Complement C3c alpha' chain fragment 1; Complement C3dg fragment; Complement C3g fragment; Complement C3d fragment; Complement C3f fragment; Complement C3c alpha' chain fragment 2]",
    "ESTD_HUMAN": "S-formylglutathione hydrolase (FGH) (EC 3.1.2.12) (Esterase D) (Methylumbelliferyl-acetate deacetylase) (EC 3.1.1.56)",
    "SCRB2_HUMAN": "Lysosome membrane protein 2 (85 kDa lysosomal membrane sialoglycoprotein) (LGP85) (CD36 antigen-like 2) (Lysosome membrane protein II) (LIMP II) (Scavenger receptor class B member 2) (CD antigen CD36)",
    "OPA3_HUMAN": "Optic atrophy 3 protein",
    "FBX2_HUMAN": "F-box only protein 2",
    "FOXD3_HUMAN": "Forkhead box protein D3 (HNF3/FH transcription factor genesis)",
    "F240C_HUMAN": "Protein FAM240C",
    "FXYD8_HUMAN": "Putative FXYD domain-containing ion transport regulator 8",
    "FOXI2_HUMAN": "Forkhead box protein I2",
    "AGRE5_HUMAN": "Adhesion G protein-coupled receptor E5 (Leukocyte antigen CD97) (CD antigen CD97) [Cleaved into: Adhesion G protein-coupled receptor E5 subunit alpha; Adhesion G protein-coupled receptor E5 subunit beta]",
    "SGCZ_HUMAN": "Zeta-sarcoglycan (Zeta-SG) (ZSG1)",
    "T179B_HUMAN": "Transmembrane protein 179B",
    "RUN3A_HUMAN": "RUN domain-containing protein 3A (Rap2-interacting protein 8) (RPIP-8)",
    "KRA99_HUMAN": "Keratin-associated protein 9-9 (Keratin-associated protein 9-5) (Keratin-associated protein 9.5) (Keratin-associated protein 9.9) (Ultrahigh sulfur keratin-associated protein 9.9)",
    "ABRX2_HUMAN": "BRISC complex subunit Abraxas 2 (Abraxas brother protein 1) (Protein FAM175B)",
    "RPGR_HUMAN": "X-linked retinitis pigmentosa GTPase regulator",
    "ZCC18_HUMAN": "Zinc finger CCHC domain-containing protein 18",
    "KR134_HUMAN": "Keratin-associated protein 13-4",
    "SOAT2_HUMAN": "Sterol O-acyltransferase 2 (EC 2.3.1.26) (Acyl-coenzyme A:cholesterol acyltransferase 2) (ACAT-2) (Cholesterol acyltransferase 2)",
    "ILK_HUMAN": "Integrin-linked protein kinase (EC 2.7.11.1) (59 kDa serine/threonine-protein kinase) (ILK-1) (ILK-2) (p59ILK)",
    "ACVR1_HUMAN": "Activin receptor type-1 (EC 2.7.11.30) (Activin receptor type I) (ACTR-I) (Activin receptor-like kinase 2) (ALK-2) (Serine/threonine-protein kinase receptor R1) (SKR1) (TGF-B superfamily receptor type I) (TSR-I)",
    "NPB13_HUMAN": "Nuclear pore complex-interacting protein family member B13",
    "KAPCA_HUMAN": "cAMP-dependent protein kinase catalytic subunit alpha (PKA C-alpha) (EC 2.7.11.11)",
    "ZN493_HUMAN": "Zinc finger protein 493",
    "NKX24_HUMAN": "Homeobox protein Nkx-2.4 (Homeobox protein NK-2 homolog D)",
    "PRP4B_HUMAN": "Serine/threonine-protein kinase PRP4 homolog (EC 2.7.11.1) (PRP4 kinase) (PRP4 pre-mRNA-processing factor 4 homolog)",
    "OR4B1_HUMAN": "Olfactory receptor 4B1 (OST208) (Olfactory receptor OR11-106)",
    "MYO3B_HUMAN": "Myosin-IIIb (EC 2.7.11.1)",
    "EXD1_HUMAN": "piRNA biogenesis protein EXD1 (Exonuclease 3'-5' domain-containing protein 1) (Exonuclease 3'-5' domain-like-containing protein 1) (Inactive exonuclease EXD1)",
    "IPP2B_HUMAN": "Protein phosphatase inhibitor 2 family member B (PPP1R2 family member B) (Protein phosphatase 1, regulatory subunit 2 pseudogene 3) (Protein phosphatase inhibitor 2-like protein 3)",
    "RCOR3_HUMAN": "REST corepressor 3",
    "MELPH_HUMAN": "Melanophilin (Exophilin-3) (Slp homolog lacking C2 domains a) (SlaC2-a) (Synaptotagmin-like protein 2a)",
    "PSG3_HUMAN": "Pregnancy-specific beta-1-glycoprotein 3 (PS-beta-G-3) (PSBG-3) (Pregnancy-specific glycoprotein 3) (Carcinoembryonic antigen SG5)",
    "TR64C_HUMAN": "Tripartite motif-containing protein 64C",
    "ATG2B_HUMAN": "Autophagy-related protein 2 homolog B",
    "YK022_HUMAN": "Putative uncharacterized protein FLJ42102",
    "SNH12_HUMAN": "Putative uncharacterized protein SNHG12 (Transformation-related gene 11 protein) (TRG-11)",
    "ATS17_HUMAN": "A disintegrin and metalloproteinase with thrombospondin motifs 17 (ADAM-TS 17) (ADAM-TS17) (ADAMTS-17) (EC 3.4.24.-)",
    "LAMA3_HUMAN": "Laminin subunit alpha-3 (Epiligrin 170 kDa subunit) (E170) (Epiligrin subunit alpha) (Kalinin subunit alpha) (Laminin-5 subunit alpha) (Laminin-6 subunit alpha) (Laminin-7 subunit alpha) (Nicein subunit alpha)",
    "PI3R4_HUMAN": "Phosphoinositide 3-kinase regulatory subunit 4 (PI3-kinase regulatory subunit 4) (EC 2.7.11.1) (PI3-kinase p150 subunit) (Phosphoinositide 3-kinase adaptor protein)",
    "MAGF1_HUMAN": "Melanoma-associated antigen F1 (MAGE-F1) (MAGE-F1 antigen)",
    "HDBP1_HUMAN": "Glycosylphosphatidylinositol-anchored high density lipoprotein-binding protein 1 (GPI-HBP1) (GPI-anchored HDL-binding protein 1) (High density lipoprotein-binding protein 1)",
    "ERIC5_HUMAN": "Glutamate-rich protein 5",
    "CALR_HUMAN": "Calreticulin (CRP55) (Calregulin) (Endoplasmic reticulum resident protein 60) (ERp60) (HACBP) (grp60)",
    "STRN4_HUMAN": "Striatin-4 (Zinedin)",
    "STPG3_HUMAN": "Protein STPG3 (Sperm-tail PG-rich repeat-containing protein 3)",
    "F180A_HUMAN": "Protein FAM180A",
    "CJ053_HUMAN": "UPF0728 protein C10orf53",
    "GPR27_HUMAN": "Probable G-protein coupled receptor 27 (Super conserved receptor expressed in brain 1)",
    "NOGG_HUMAN": "Noggin",
    "ENTP6_HUMAN": "Ectonucleoside triphosphate diphosphohydrolase 6 (NTPDase 6) (EC 3.6.1.6) (CD39 antigen-like 2)",
    "HV349_HUMAN": "Immunoglobulin heavy variable 3-49",
    "KIF4A_HUMAN": "Chromosome-associated kinesin KIF4A (Chromokinesin-A)",
    "NXF2_HUMAN": "Nuclear RNA export factor 2 (Cancer/testis antigen 39) (CT39) (TAP-like protein 2) (TAPL-2)",
    "CK072_HUMAN": "Uncharacterized protein C11orf72",
    "CXB6_HUMAN": "Gap junction beta-6 protein (Connexin-30) (Cx30)",
    "BT3L4_HUMAN": "Transcription factor BTF3 homolog 4 (Basic transcription factor 3-like 4)",
    "PGCA_HUMAN": "Aggrecan core protein (Cartilage-specific proteoglycan core protein) (CSPCP) (Chondroitin sulfate proteoglycan core protein 1) (Chondroitin sulfate proteoglycan 1) [Cleaved into: Aggrecan core protein 2]",
    "NAA16_HUMAN": "N-alpha-acetyltransferase 16, NatA auxiliary subunit (NMDA receptor-regulated 1-like protein) (NARG1-like protein)",
    "IG2R_HUMAN": "Putative insulin-like growth factor 2-associated protein (Cell growth-inhibiting gene 44 protein) (Insulin-like growth factor II-associated protein)",
    "RPGR1_HUMAN": "X-linked retinitis pigmentosa GTPase regulator-interacting protein 1 (RPGR-interacting protein 1)",
    "YQ037_HUMAN": "Putative uncharacterized protein FLJ38767",
    "KPYM_HUMAN": "Pyruvate kinase PKM (EC 2.7.1.40) (Cytosolic thyroid hormone-binding protein) (CTHBP) (Opa-interacting protein 3) (OIP-3) (Pyruvate kinase 2/3) (Pyruvate kinase muscle isozyme) (Thyroid hormone-binding protein 1) (THBP1) (Tumor M2-PK) (p58)",
    "DP13B_HUMAN": "DCC-interacting protein 13-beta (Dip13-beta) (Adapter protein containing PH domain, PTB domain and leucine zipper motif 2)",
    "TULP1_HUMAN": "Tubby-related protein 1 (Tubby-like protein 1)",
    "CL065_HUMAN": "Probable peptide chain release factor C12orf65, mitochondrial",
    "CNGB1_HUMAN": "Cyclic nucleotide-gated cation channel beta-1 (Cyclic nucleotide-gated cation channel 4) (CNG channel 4) (CNG-4) (CNG4) (Cyclic nucleotide-gated cation channel gamma) (Cyclic nucleotide-gated cation channel modulatory subunit) (Cyclic nucleotide-gated channel beta-1) (CNG channel beta-1) (Glutamic acid-rich protein) (GARP)",
    "CI014_HUMAN": "Putative uncharacterized protein encoded by LINC00032",
    "RETR3_HUMAN": "Reticulophagy regulator 3",
    "AGRF4_HUMAN": "Adhesion G protein-coupled receptor F4 (G-protein coupled receptor 115) (G-protein coupled receptor PGR18)",
    "NSE3_HUMAN": "Non-structural maintenance of chromosomes element 3 homolog (Non-SMC element 3 homolog) (Hepatocellular carcinoma-associated protein 4) (MAGE-G1 antigen) (Melanoma-associated antigen G1) (Necdin-like protein 2)",
    "PTPRZ_HUMAN": "Receptor-type tyrosine-protein phosphatase zeta (R-PTP-zeta) (EC 3.1.3.48) (Protein-tyrosine phosphatase receptor type Z polypeptide 1) (Protein-tyrosine phosphatase receptor type Z polypeptide 2) (R-PTP-zeta-2)",
    "COPRS_HUMAN": "Coordinator of PRMT5 and differentiation stimulator (Cooperator of PRMT5) (Protein TTP1)",
    "DEF6_HUMAN": "Defensin-6 (Defensin, alpha 6)",
    "CS025_HUMAN": "UPF0449 protein C19orf25",
    "ASTRA_HUMAN": "Protein Aster-A (GRAM domain-containing protein 1A)",
    "PABP2_HUMAN": "Polyadenylate-binding protein 2 (PABP-2) (Poly(A)-binding protein 2) (Nuclear poly(A)-binding protein 1) (Poly(A)-binding protein II) (PABII) (Polyadenylate-binding nuclear protein 1)",
    "ENTP8_HUMAN": "Ectonucleoside triphosphate diphosphohydrolase 8 (E-NTPDase 8) (NTPDase 8) (NTPDase8) (EC 3.6.1.5)",
    "SRSF2_HUMAN": "Serine/arginine-rich splicing factor 2 (Protein PR264) (Splicing component, 35 kDa) (Splicing factor SC35) (SC-35) (Splicing factor, arginine/serine-rich 2)",
    "EX3L2_HUMAN": "Exocyst complex component 3-like protein 2 (HBV X-transactivated gene 7 protein) (HBV XAg-transactivated protein 7)",
    "APMAP_HUMAN": "Adipocyte plasma membrane-associated protein (Protein BSCv)",
    "F210A_HUMAN": "Protein FAM210A",
    "UBP19_HUMAN": "Ubiquitin carboxyl-terminal hydrolase 19 (EC 3.4.19.12) (Deubiquitinating enzyme 19) (Ubiquitin thioesterase 19) (Ubiquitin-specific-processing protease 19) (Zinc finger MYND domain-containing protein 9)",
    "K2C78_HUMAN": "Keratin, type II cytoskeletal 78 (Cytokeratin-78) (CK-78) (Keratin-5b) (Keratin-78) (K78) (Type-II keratin Kb40)",
    "SND1_HUMAN": "Staphylococcal nuclease domain-containing protein 1 (EC 3.1.31.1) (100 kDa coactivator) (EBNA2 coactivator p100) (Tudor domain-containing protein 11) (p100 co-activator)",
    "ADA12_HUMAN": "Disintegrin and metalloproteinase domain-containing protein 12 (ADAM 12) (EC 3.4.24.-) (Meltrin-alpha)",
    "OR8K3_HUMAN": "Olfactory receptor 8K3 (Olfactory receptor OR11-181)",
    "UT14A_HUMAN": "U3 small nucleolar RNA-associated protein 14 homolog A (Antigen NY-CO-16) (Serologically defined colon cancer antigen 16)",
    "GPR82_HUMAN": "Probable G-protein coupled receptor 82",
    "MEP1B_HUMAN": "Meprin A subunit beta (EC 3.4.24.63) (Endopeptidase-2) (Meprin B) (N-benzoyl-L-tyrosyl-P-amino-benzoic acid hydrolase subunit beta) (PABA peptide hydrolase) (PPH beta)",
    "CABP5_HUMAN": "Calcium-binding protein 5 (CaBP5)",
    "RGF1B_HUMAN": "Ras-GEF domain-containing family member 1B (GPI gamma-4)",
    "FANCL_HUMAN": "E3 ubiquitin-protein ligase FANCL (EC 2.3.2.27) (Fanconi anemia group L protein) (Fanconi anemia-associated polypeptide of 43 kDa) (FAAP43) (RING-type E3 ubiquitin transferase FANCL)",
    "RGCC_HUMAN": "Regulator of cell cycle RGCC (Response gene to complement 32 protein) (RGC-32)",
    "ARHG7_HUMAN": "Rho guanine nucleotide exchange factor 7 (Beta-Pix) (COOL-1) (PAK-interacting exchange factor beta) (p85)",
    "CCD62_HUMAN": "Coiled-coil domain-containing protein 62 (Protein TSP-NY) (Protein aaa)",
    "CRIP1_HUMAN": "Cysteine-rich protein 1 (CRP-1) (Cysteine-rich heart protein) (CRHP) (hCRHP) (Cysteine-rich intestinal protein) (CRIP)",
    "U2AFM_HUMAN": "U2 small nuclear ribonucleoprotein auxiliary factor 35 kDa subunit-related protein 2 (CCCH type zinc finger, RNA-binding motif and serine/arginine rich protein 2) (Renal carcinoma antigen NY-REN-20) (U2(RNU2) small nuclear RNA auxiliary factor 1-like 2) (U2AF35-related protein) (URP)",
    "TAM41_HUMAN": "Phosphatidate cytidylyltransferase, mitochondrial (EC 2.7.7.41) (CDP-diacylglycerol synthase) (CDP-DAG synthase) (Mitochondrial translocator assembly and maintenance protein 41 homolog) (TAM41)",
    "LGR5_HUMAN": "Leucine-rich repeat-containing G-protein coupled receptor 5 (G-protein coupled receptor 49) (G-protein coupled receptor 67) (G-protein coupled receptor HG38)",
    "KCNN3_HUMAN": "Small conductance calcium-activated potassium channel protein 3 (SK3) (SKCa 3) (SKCa3) (KCa2.3)",
    "RHOC_HUMAN": "Rho-related GTP-binding protein RhoC (Rho cDNA clone 9) (h9)",
    "AT1B3_HUMAN": "Sodium/potassium-transporting ATPase subunit beta-3 (Sodium/potassium-dependent ATPase subunit beta-3) (ATPB-3) (CD antigen CD298)",
    "ADA15_HUMAN": "Disintegrin and metalloproteinase domain-containing protein 15 (ADAM 15) (EC 3.4.24.-) (Metalloprotease RGD disintegrin protein) (Metalloproteinase-like, disintegrin-like, and cysteine-rich protein 15) (MDC-15) (Metargidin)",
    "SOX9_HUMAN": "Transcription factor SOX-9",
    "MGP_HUMAN": "Matrix Gla protein (MGP) (Cell growth-inhibiting gene 36 protein)",
    "ZDBF2_HUMAN": "DBF4-type zinc finger-containing protein 2",
    "PYDC2_HUMAN": "Pyrin domain-containing protein 2 (Pyrin-only protein 2) (cellular POP2) (cPOP2)",
    "E4F1_HUMAN": "Transcription factor E4F1 (EC 2.3.2.27) (E4F transcription factor 1) (Putative E3 ubiquitin-protein ligase E4F1) (RING-type E3 ubiquitin transferase E4F1) (Transcription factor E4F) (p120E4F) (p50E4F)",
    "FFAR1_HUMAN": "Free fatty acid receptor 1 (G-protein coupled receptor 40)",
    "IMP1L_HUMAN": "Mitochondrial inner membrane protease subunit 1 (EC 3.4.21.-) (IMP1-like protein)",
    "RDH5_HUMAN": "Retinol dehydrogenase 5 (EC 1.1.1.209) (EC 1.1.1.315) (EC 1.1.1.53) (11-cis retinol dehydrogenase) (11-cis RDH) (11-cis RoDH) (9-cis retinol dehydrogenase) (9cRDH) (Short chain dehydrogenase/reductase family 9C member 5)",
    "CNIH2_HUMAN": "Protein cornichon homolog 2 (CNIH-2) (Cornichon family AMPA receptor auxiliary protein 2) (Cornichon-like protein)",
    "YM017_HUMAN": "Putative UPF0607 protein ENSP00000383144",
    "ZN471_HUMAN": "Zinc finger protein 471 (EZFIT-related protein 1)",
    "ARI4B_HUMAN": "AT-rich interactive domain-containing protein 4B (ARID domain-containing protein 4B) (180 kDa Sin3-associated polypeptide) (Sin3-associated polypeptide p180) (Breast cancer-associated antigen BRCAA1) (Histone deacetylase complex subunit SAP180) (Retinoblastoma-binding protein 1-like 1)",
    "ANR52_HUMAN": "Serine/threonine-protein phosphatase 6 regulatory ankyrin repeat subunit C (PP6-ARS-C) (Serine/threonine-protein phosphatase 6 regulatory subunit ARS-C) (Ankyrin repeat domain-containing protein 52)",
    "C1S_HUMAN": "Complement C1s subcomponent (EC 3.4.21.42) (C1 esterase) (Complement component 1 subcomponent s) [Cleaved into: Complement C1s subcomponent heavy chain; Complement C1s subcomponent light chain]",
    "DCA15_HUMAN": "DDB1- and CUL4-associated factor 15",
    "PAFA_HUMAN": "Platelet-activating factor acetylhydrolase (PAF acetylhydrolase) (EC 3.1.1.47) (1-alkyl-2-acetylglycerophosphocholine esterase) (2-acetyl-1-alkylglycerophosphocholine esterase) (Group-VIIA phospholipase A2) (gVIIA-PLA2) (LDL-associated phospholipase A2) (LDL-PLA(2)) (PAF 2-acylhydrolase)",
    "S23A2_HUMAN": "Solute carrier family 23 member 2 (Na(+)/L-ascorbic acid transporter 2) (Nucleobase transporter-like 1 protein) (Sodium-dependent vitamin C transporter 2) (hSVCT2) (Yolk sac permease-like molecule 2)",
    "VPREB_HUMAN": "Immunoglobulin iota chain (CD179 antigen-like family member A) (Protein VPreB1) (V(pre)B protein) (VpreB protein) (CD antigen CD179a)",
    "NRSN2_HUMAN": "Neurensin-2",
    "S31A1_HUMAN": "Spermatogenesis-associated protein 31A1 (Protein FAM75A1)",
    "STAG2_HUMAN": "Cohesin subunit SA-2 (SCC3 homolog 2) (Stromal antigen 2)",
    "DCNL5_HUMAN": "DCN1-like protein 5 (DCUN1 domain-containing protein 5) (Defective in cullin neddylation protein 1-like protein 5)",
    "LACC1_HUMAN": "Purine nucleoside phosphorylase LACC1 (EC 2.4.2.1) (Adenosine deaminase LACC1) (EC 3.5.4.4) (Fatty acid metabolism-immunity nexus) (Guanosine phosphorylase LACC1) (Laccase domain-containing protein 1) (S-methyl-5'-thioadenosine phosphorylase LACC1) (EC 2.4.2.28)",
    "GPHB5_HUMAN": "Glycoprotein hormone beta-5 (Thyrostimulin subunit beta)",
    "AJAP1_HUMAN": "Adherens junction-associated protein 1 (Membrane protein shrew-1)",
    "CT085_HUMAN": "Uncharacterized protein C20orf85",
    "CLM8_HUMAN": "CMRF35-like molecule 8 (CLM-8) (CD300 antigen-like family member A) (CMRF-35-H9) (CMRF35-H9) (CMRF35-H) (IRC1/IRC2) (Immunoglobulin superfamily member 12) (IgSF12) (Inhibitory receptor protein 60) (IRp60) (NK inhibitory receptor) (CD antigen CD300a)",
    "GBRL3_HUMAN": "Gamma-aminobutyric acid receptor-associated protein-like 3 (GABA(A) receptor-associated protein-like 3)",
    "PDC6I_HUMAN": "Programmed cell death 6-interacting protein (PDCD6-interacting protein) (ALG-2-interacting protein 1) (ALG-2-interacting protein X) (Hp95)",
    "TR5OS_HUMAN": "Putative uncharacterized protein TRPC5OS (TRPC5 opposite strand protein) (TRPC5-antisense RNA 1)",
    "LEU7_HUMAN": "Leukemia-associated protein 7 (Deleted in lymphocytic leukemia 7)",
    "HMCES_HUMAN": "Abasic site processing protein HMCES (Embryonic stem cell-specific 5-hydroxymethylcytosine-binding protein) (ES cell-specific 5hmC-binding protein) (Peptidase HMCES) (EC 3.4.-.-) (SRAP domain-containing protein 1)",
    "ZN732_HUMAN": "Zinc finger protein 732",
    "PROK1_HUMAN": "Prokineticin-1 (Endocrine-gland-derived vascular endothelial growth factor) (EG-VEGF) (Mambakine)",
    "NKX63_HUMAN": "Homeobox protein Nkx-6.3",
    "CADH7_HUMAN": "Cadherin-7",
    "PHIPL_HUMAN": "Phytanoyl-CoA hydroxylase-interacting protein-like",
    "WDR90_HUMAN": "WD repeat-containing protein 90",
    "U2AF1_HUMAN": "Splicing factor U2AF 35 kDa subunit (U2 auxiliary factor 35 kDa subunit) (U2 small nuclear RNA auxiliary factor 1) (U2 snRNP auxiliary factor small subunit)",
    "P4HTM_HUMAN": "Transmembrane prolyl 4-hydroxylase (P4H-TM) (EC 1.14.11.29) (Hypoxia-inducible factor prolyl hydroxylase 4) (HIF-PH4) (HIF-prolyl hydroxylase 4) (HPH-4)",
    "PROC_HUMAN": "Vitamin K-dependent protein C (EC 3.4.21.69) (Anticoagulant protein C) (Autoprothrombin IIA) (Blood coagulation factor XIV) [Cleaved into: Vitamin K-dependent protein C light chain; Vitamin K-dependent protein C heavy chain; Activation peptide]",
    "PSMG4_HUMAN": "Proteasome assembly chaperone 4 (PAC-4) (hPAC4)",
    "IGE_HUMAN": "Immunoglobulin epsilon heavy chain (Immunoglobulin epsilon heavy chain ND)",
    "RS28_HUMAN": "40S ribosomal protein S28 (Small ribosomal subunit protein eS28)",
    "SPXN2_HUMAN": "Sperm protein associated with the nucleus on the X chromosome N2 (Nuclear-associated protein SPAN-Xn2) (SPANX-N2) (SPANX family member N2)",
    "NRG2_HUMAN": "Pro-neuregulin-2, membrane-bound isoform (Pro-NRG2) [Cleaved into: Neuregulin-2 (NRG-2) (Divergent of neuregulin-1) (DON-1) (Neural- and thymus-derived activator for ERBB kinases) (NTAK)]",
    "MMAA_HUMAN": "Methylmalonic aciduria type A protein, mitochondrial (EC 3.6.-.-)",
    "RB27A_HUMAN": "Ras-related protein Rab-27A (Rab-27) (EC 3.6.5.2) (GTP-binding protein Ram)",
    "ZN689_HUMAN": "Zinc finger protein 689",
    "PO5F1_HUMAN": "POU domain, class 5, transcription factor 1 (Octamer-binding protein 3) (Oct-3) (Octamer-binding protein 4) (Oct-4) (Octamer-binding transcription factor 3) (OTF-3)",
    "DEN11_HUMAN": "DENN domain-containing protein 11 (DENND11) (Protein LCHN)",
    "AT1A4_HUMAN": "Sodium/potassium-transporting ATPase subunit alpha-4 (Na(+)/K(+) ATPase alpha-4 subunit) (EC 7.2.2.13) (Sodium pump subunit alpha-4)",
    "NBPFF_HUMAN": "Neuroblastoma breakpoint family member 15 (Neuroblastoma breakpoint family member 16)",
    "OFCC1_HUMAN": "Orofacial cleft 1 candidate gene 1 protein (Orofacial clefting chromosomal breakpoint region candidate 1 protein)",
    "AT5G2_HUMAN": "ATP synthase F(0) complex subunit C2, mitochondrial (ATP synthase lipid-binding protein) (ATP synthase membrane subunit c locus 2) (ATP synthase proteolipid P2) (ATP synthase proton-transporting mitochondrial F(0) complex subunit C2) (ATPase protein 9) (ATPase subunit c)",
    "RBAS1_HUMAN": "Putative uncharacterized protein encoded by RBM12B-AS1 (RBM12B antisense RNA 1) (RBM12B antisense gene protein 1)",
    "TSPYA_HUMAN": "Testis-specific Y-encoded protein 10",
    "ENTP7_HUMAN": "Ectonucleoside triphosphate diphosphohydrolase 7 (NTPDase 7) (EC 3.6.1.-) (Lysosomal apyrase-like protein 1)",
    "CF206_HUMAN": "Cilia- and flagella-associated protein 206",
    "F184B_HUMAN": "Protein FAM184B",
    "DYRK4_HUMAN": "Dual specificity tyrosine-phosphorylation-regulated kinase 4 (EC 2.7.12.1)",
    "S52A3_HUMAN": "Solute carrier family 52, riboflavin transporter, member 3 (Riboflavin transporter 2) (hRFT2)",
    "GUF1_HUMAN": "Translation factor GUF1, mitochondrial (EC 3.6.5.-) (Elongation factor 4 homolog) (EF-4) (GTPase GUF1) (Ribosomal back-translocase)",
    "CD045_HUMAN": "Uncharacterized protein C4orf45",
    "MATN1_HUMAN": "Cartilage matrix protein (Matrilin-1)",
    "CPPED_HUMAN": "Serine/threonine-protein phosphatase CPPED1 (EC 3.1.3.16) (Calcineurin-like phosphoesterase domain-containing protein 1) (Complete S-transactivated protein 1)",
    "A2012_HUMAN": "Putative ankyrin repeat domain-containing protein 20A12 pseudogene",
    "S6A19_HUMAN": "Sodium-dependent neutral amino acid transporter B(0)AT1 (Solute carrier family 6 member 19) (System B(0) neutral amino acid transporter AT1)",
    "AIFM3_HUMAN": "Apoptosis-inducing factor 3 (EC 1.-.-.-) (Apoptosis-inducing factor-like protein)",
    "SP17_HUMAN": "Sperm surface protein Sp17 (Cancer/testis antigen 22) (CT22) (Sp17-1) (Sperm autoantigenic protein 17) (Sperm protein 17)",
    "NKPD1_HUMAN": "NTPase KAP family P-loop domain-containing protein 1",
    "CX062_HUMAN": "Putative uncharacterized protein encoded by LINC00269",
    "GALT6_HUMAN": "Polypeptide N-acetylgalactosaminyltransferase 6 (EC 2.4.1.41) (Polypeptide GalNAc transferase 6) (GalNAc-T6) (pp-GaNTase 6) (Protein-UDP acetylgalactosaminyltransferase 6) (UDP-GalNAc:polypeptide N-acetylgalactosaminyltransferase 6)",
    "GOG8Q_HUMAN": "Golgin subfamily A member 8Q",
    "CBPQ_HUMAN": "Carboxypeptidase Q (EC 3.4.17.-) (Lysosomal dipeptidase) (Plasma glutamate carboxypeptidase)",
    "VDAC1_HUMAN": "Voltage-dependent anion-selective channel protein 1 (VDAC-1) (hVDAC1) (Outer mitochondrial membrane protein porin 1) (Plasmalemmal porin) (Porin 31HL) (Porin 31HM)",
    "IBP2_HUMAN": "Insulin-like growth factor-binding protein 2 (IBP-2) (IGF-binding protein 2) (IGFBP-2)",
    "ETV3_HUMAN": "ETS translocation variant 3 (ETS domain transcriptional repressor PE1) (PE-1) (Mitogenic Ets transcriptional suppressor)",
    "TCO2_HUMAN": "Transcobalamin-2 (TC-2) (Transcobalamin II) (TC II) (TCII)",
    "TJA42_HUMAN": "T cell receptor alpha joining 42",
    "PR20A_HUMAN": "Proline-rich protein 20A",
    "SLX4_HUMAN": "Structure-specific endonuclease subunit SLX4 (BTB/POZ domain-containing protein 12)",
    "NYAP1_HUMAN": "Neuronal tyrosine-phosphorylated phosphoinositide-3-kinase adapter 1",
    "NGBR_HUMAN": "Dehydrodolichyl diphosphate synthase complex subunit NUS1 (EC 2.5.1.87) (Cis-prenyltransferase subunit NgBR) (Nogo-B receptor) (NgBR) (Nuclear undecaprenyl pyrophosphate synthase 1 homolog)",
    "CENPP_HUMAN": "Centromere protein P (CENP-P)",
    "ADA11_HUMAN": "Disintegrin and metalloproteinase domain-containing protein 11 (ADAM 11) (Metalloproteinase-like, disintegrin-like, and cysteine-rich protein) (MDC)",
    "PRGR_HUMAN": "Progesterone receptor (PR) (Nuclear receptor subfamily 3 group C member 3)",
    "CCD18_HUMAN": "Coiled-coil domain-containing protein 18 (Sarcoma antigen NY-SAR-24)",
    "ABHD6_HUMAN": "Monoacylglycerol lipase ABHD6 (EC 3.1.1.23) (2-arachidonoylglycerol hydrolase) (Abhydrolase domain-containing protein 6)",
    "SOCS2_HUMAN": "Suppressor of cytokine signaling 2 (SOCS-2) (Cytokine-inducible SH2 protein 2) (CIS-2) (STAT-induced STAT inhibitor 2) (SSI-2)",
    "CTND2_HUMAN": "Catenin delta-2 (Delta-catenin) (GT24) (Neural plakophilin-related ARM-repeat protein) (NPRAP) (Neurojungin)",
    "T2R36_HUMAN": "Putative taste receptor type 2 member 36 (T2R36) (hGR36)",
    "GDIR1_HUMAN": "Rho GDP-dissociation inhibitor 1 (Rho GDI 1) (Rho-GDI alpha)",
    "SARDH_HUMAN": "Sarcosine dehydrogenase, mitochondrial (SarDH) (EC 1.5.8.3) (BPR-2)",
    "TM2D1_HUMAN": "TM2 domain-containing protein 1 (Amyloid-beta-binding protein) (hBBP)",
    "LIGO1_HUMAN": "Leucine-rich repeat and immunoglobulin-like domain-containing nogo receptor-interacting protein 1 (Leucine-rich repeat and immunoglobulin domain-containing protein 1) (Leucine-rich repeat neuronal protein 1) (Leucine-rich repeat neuronal protein 6A)",
    "CHSTA_HUMAN": "Carbohydrate sulfotransferase 10 (EC 2.8.2.-) (HNK-1 sulfotransferase) (HNK-1ST) (HNK1ST) (HuHNK-1ST)",
    "CADM3_HUMAN": "Cell adhesion molecule 3 (Brain immunoglobulin receptor) (Immunoglobulin superfamily member 4B) (IgSF4B) (Nectin-like protein 1) (NECL-1) (Synaptic cell adhesion molecule 3) (SynCAM3) (TSLC1-like protein 1) (TSLL1)",
    "F86B1_HUMAN": "Putative protein N-methyltransferase FAM86B1 (EC 2.1.1.-)",
    "OR8K1_HUMAN": "Olfactory receptor 8K1 (Olfactory receptor OR11-182)",
    "LR75A_HUMAN": "Leucine-rich repeat-containing protein 75A (Leucine-rich repeat-containing protein FAM211A)",
    "TBC3A_HUMAN": "TBC1 domain family member 3 (Prostate cancer gene 17 protein) (Protein TRE17-alpha) (Rab GTPase-activating protein PRC17)",
    "T126B_HUMAN": "Complex I assembly factor TMEM126B, mitochondrial (Transmembrane protein 126B)",
    "SPR2D_HUMAN": "Small proline-rich protein 2D (SPR-2D) (Small proline-rich protein II) (SPR-II)",
    "GSTO1_HUMAN": "Glutathione S-transferase omega-1 (GSTO-1) (EC 2.5.1.18) (Glutathione S-transferase omega 1-1) (GSTO 1-1) (Glutathione-dependent dehydroascorbate reductase) (EC 1.8.5.1) (Monomethylarsonic acid reductase) (MMA(V) reductase) (EC 1.20.4.2) (S-(Phenacyl)glutathione reductase) (SPG-R)",
    "BAZ2A_HUMAN": "Bromodomain adjacent to zinc finger domain protein 2A (Transcription termination factor I-interacting protein 5) (TTF-I-interacting protein 5) (Tip5) (hWALp3)",
    "ST3L4_HUMAN": "Putative STAG3-like protein 4 (Stromal antigen 3-like protein 4)",
    "TPH2_HUMAN": "Tryptophan 5-hydroxylase 2 (EC 1.14.16.4) (Neuronal tryptophan hydroxylase) (Tryptophan 5-monooxygenase 2)",
    "HV315_HUMAN": "Immunoglobulin heavy variable 3-15",
    "CSAG1_HUMAN": "Putative chondrosarcoma-associated gene 1 protein (Cancer/testis antigen 24.1) (CT24.1) (Cancer/testis antigen CSAGE)",
    "F228B_HUMAN": "Protein FAM228B",
    "FMO1_HUMAN": "Dimethylaniline monooxygenase [N-oxide-forming] 1 (EC 1.14.13.8) (Dimethylaniline oxidase 1) (Fetal hepatic flavin-containing monooxygenase 1) (FMO 1)",
    "NK1R_HUMAN": "Substance-P receptor (SPR) (NK-1 receptor) (NK-1R) (Tachykinin receptor 1)",
    "RENR_HUMAN": "Renin receptor (ATPase H(+)-transporting lysosomal accessory protein 2) (ATPase H(+)-transporting lysosomal-interacting protein 2) (ER-localized type I transmembrane adaptor) (Embryonic liver differentiation factor 10) (N14F) (Renin/prorenin receptor) (Vacuolar ATP synthase membrane sector-associated protein M8-9) (ATP6M8-9) (V-ATPase M8.9 subunit) [Cleaved into: Renin receptor N-terminal fragment; Renin receptor C-terminal fragment]",
    "PDLI7_HUMAN": "PDZ and LIM domain protein 7 (LIM mineralization protein) (LMP) (Protein enigma)",
    "VSIG8_HUMAN": "V-set and immunoglobulin domain-containing protein 8",
    "S31D4_HUMAN": "Spermatogenesis-associated protein 31D4 (Protein FAM75D4)",
    "MEIG1_HUMAN": "Meiosis expressed gene 1 protein homolog",
    "KR131_HUMAN": "Keratin-associated protein 13-1 (High sulfur keratin-associated protein 13.1)",
    "ARP19_HUMAN": "cAMP-regulated phosphoprotein 19 (ARPP-19)",
    "KLHL8_HUMAN": "Kelch-like protein 8",
    "CU067_HUMAN": "Uncharacterized protein encoded by LINC01547",
    "RF1ML_HUMAN": "Peptide chain release factor 1-like, mitochondrial (Mitochondrial translational release factor 1-like) (mtRF1a)",
    "O5AK2_HUMAN": "Olfactory receptor 5AK2",
    "PRR30_HUMAN": "Proline-rich protein 30",
    "SAP18_HUMAN": "Histone deacetylase complex subunit SAP18 (18 kDa Sin3-associated polypeptide) (2HOR0202) (Cell growth-inhibiting gene 38 protein) (Sin3-associated polypeptide p18)",
    "NUCKS_HUMAN": "Nuclear ubiquitous casein and cyclin-dependent kinase substrate 1 (P1)",
    "41_HUMAN": "Protein 4.1 (P4.1) (4.1R) (Band 4.1) (EPB4.1)",
    "SMCO4_HUMAN": "Single-pass membrane and coiled-coil domain-containing protein 4 (Protein FN5)",
    "CLD15_HUMAN": "Claudin-15",
    "NOTC3_HUMAN": "Neurogenic locus notch homolog protein 3 (Notch 3) [Cleaved into: Notch 3 extracellular truncation; Notch 3 intracellular domain]",
    "CR063_HUMAN": "Uncharacterized protein C18orf63",
    "KV229_HUMAN": "Immunoglobulin kappa variable 2-29",
    "KCNJ8_HUMAN": "ATP-sensitive inward rectifier potassium channel 8 (Inward rectifier K(+) channel Kir6.1) (Potassium channel, inwardly rectifying subfamily J member 8) (uKATP-1)",
    "S49A3_HUMAN": "Solute carrier family 49 member A3 (Major facilitator superfamily domain-containing protein 7) (Myosin light polypeptide 5 regulatory protein) (MYL5)",
    "GHC2_HUMAN": "Mitochondrial glutamate carrier 2 (GC-2) (Glutamate/H(+) symporter 2) (Solute carrier family 25 member 18)",
    "NDF6_HUMAN": "Neurogenic differentiation factor 6 (NeuroD6) (Class A basic helix-loop-helix protein 2) (bHLHa2) (Protein atonal homolog 2)",
    "PADI3_HUMAN": "Protein-arginine deiminase type-3 (EC 3.5.3.15) (Peptidylarginine deiminase III) (Protein-arginine deiminase type III)",
    "LMOD3_HUMAN": "Leiomodin-3 (Leiomodin, fetal form)",
    "TMC5_HUMAN": "Transmembrane channel-like protein 5",
    "CAN5_HUMAN": "Calpain-5 (EC 3.4.22.-) (Calpain htra-3) (New calpain 3) (nCL-3)",
    "MIOX_HUMAN": "Inositol oxygenase (EC 1.13.99.1) (Aldehyde reductase-like 6) (Kidney-specific protein 32) (Myo-inositol oxygenase) (MI oxygenase) (Renal-specific oxidoreductase)",
    "COG1_HUMAN": "Conserved oligomeric Golgi complex subunit 1 (COG complex subunit 1) (Component of oligomeric Golgi complex 1)",
    "KLF9_HUMAN": "Krueppel-like factor 9 (Basic transcription element-binding protein 1) (BTE-binding protein 1) (GC-box-binding protein 1) (Transcription factor BTEB1)",
    "UNC79_HUMAN": "Protein unc-79 homolog",
    "HYCCI_HUMAN": "Hyccin (Down-regulated by CTNNB1 protein A) (Protein FAM126A)",
    "IQCC_HUMAN": "IQ domain-containing protein C",
}


AminoAcid = namedtuple('AminoAcid', ['full_name', 'three_letters_name', 'one_letter_name', 'mass'])

amino_acids = [
    AminoAcid("Alanine", "Ala", "A", 71),
    AminoAcid("Arginine", "Arg", "R", 156),
    AminoAcid("Asparagine", "Asn", "N", 114),
    AminoAcid("Aspartic Acid", "Asp", "D", 115),
    AminoAcid("Cysteine", "Cys", "C", 103),
    AminoAcid("Glutamic Acid", "Glu", "E", 129),
    AminoAcid("Glutamine", "Gln", "Q", 128),
    AminoAcid("Glycine", "Gly", "G", 57),
    AminoAcid("Histidine", "His", "H", 137),
    AminoAcid("Isoleucine", "Ile", "I", 113),
    AminoAcid("Leucine", "Leu", "L", 113),
    AminoAcid("Lysine", "Lys", "K", 128),
    AminoAcid("Methionine", "Met", "M", 131),
    AminoAcid("Phenylalanine", "Phe", "F", 147),
    AminoAcid("Proline", "Pro", "P", 97),
    AminoAcid("Serine", "Ser", "S", 87),
    AminoAcid("Threonine", "Thr", "T", 101),
    AminoAcid("Tryptophan", "Trp", "W", 186),
    AminoAcid("Tyrosine", "Tyr", "Y", 163),
    AminoAcid("Valine", "Val", "V", 99),
]



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb 13 10:27:03 2022

@author: richard
"""

import unittest
from faker import Faker
from faker_biology.physiology import Organ


fake = Faker()
fake.add_provider(Organ)
organ_provider = Organ(None)


class OrganTest(unittest.TestCase):
    def test_organ_categories(self):
        self.assertEqual(13, len(organ_provider.categories()))

    def test_random_organ(self):
        organ_set = set([fake.unique.organ() for i in range(15)])
        self.assertEqual(15, len(organ_set))

    def test_non_reproductive_organ(self):
        organs = [fake.unique.non_reproductive_organ() for i in range(70)]
        self.assertFalse("Ovaries" in organs)



from collections import namedtuple

## these 2 lists should be equal length
MODEL_ORGANISMS_ENGLISH = [
    "Fly",
    "Mouse",
    "Nematode",
    "Rat",
    "Xenopus",
    "Fission yeast",
    "Budding Yeast",
    "Zebrafish",
]


MODEL_ORGANISMS_LATIN = [
    "Drosophila melanogaster",
    "Mus musculus",
    "Caenorhabditis elegans",
    "Rattus norvegicus",
    "Xenopus laevis",
    "Schizosaccharomyces pombe",
    "Saccharomyces cervisiae",
    "Danio Rerio",
]

MODEL_ORGANISM = namedtuple("model_organism", ["english", "latin"])

zipped = zip(MODEL_ORGANISMS_ENGLISH, MODEL_ORGANISMS_LATIN)
list_zipped = list(zipped)
MODEL_ORGANISMS = [MODEL_ORGANISM(*mo) for mo in list_zipped]







#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb 13 10:27:03 2022

@author: richard
"""

import unittest
from faker import Faker
from faker_biology.mol_biol import Enzyme


fake = Faker()
fake.add_provider(Enzyme)
enzyme_provider = Enzyme(None)


class EnzymeTest(unittest.TestCase):
    def test_enzyme_categories(self):
        self.assertEqual(6, len(enzyme_provider.categories()))

    def test_random_enzyme(self):
        total_enzyme_count = 150
        enzymes = set([fake.unique.enzyme() for i in range(total_enzyme_count)])
        self.assertEqual(total_enzyme_count, len(enzymes))

    def test_random_category(self):
        enzymes = set([fake.unique.enzyme_category() for i in range(50)])
        self.assertEqual(50, len(enzymes))
